# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_access_tiers_stats.get import V1AccessTiersStatsGet
from banyanclient.paths.v1_one_click_support_bundle.post import V1OneClickSupportBundlePost
from banyanclient.paths.v1_service_hostname_mapping.get import V1ServiceHostnameMappingGet
from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id.delete import V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdDelete
from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id.post import V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdPost
from banyanclient.paths.v2_access_tier.get import V2AccessTierGet
from banyanclient.paths.v2_access_tier_id.delete import V2AccessTierIdDelete
from banyanclient.paths.v2_access_tier_id.get import V2AccessTierIdGet
from banyanclient.paths.v2_access_tier_id.put import V2AccessTierIdPut
from banyanclient.paths.v2_access_tier_id_registered_services.get import V2AccessTierIdRegisteredServicesGet
from banyanclient.paths.v2_access_tier.post import V2AccessTierPost


class AccessTierApi(
    V1AccessTiersStatsGet,
    V1OneClickSupportBundlePost,
    V1ServiceHostnameMappingGet,
    V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdDelete,
    V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdPost,
    V2AccessTierGet,
    V2AccessTierIdDelete,
    V2AccessTierIdGet,
    V2AccessTierIdPut,
    V2AccessTierIdRegisteredServicesGet,
    V2AccessTierPost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
