from banyanclient.paths.v2_access_tier_id.get import ApiForget
from banyanclient.paths.v2_access_tier_id.put import ApiForput
from banyanclient.paths.v2_access_tier_id.delete import ApiFordelete


class V2AccessTierId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
