# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id import Api

from banyanclient.paths import PathValues

path = PathValues.V2_ACCESS_TIER_ACCESS_TIER_ID_TUNNEL_CONFIG_TUNNEL_CONFIG_ID