# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v2_connector_stats.get import V2ConnectorStatsGet
from banyanclient.paths.v2_satellite.get import V2SatelliteGet
from banyanclient.paths.v2_satellite_id.delete import V2SatelliteIdDelete
from banyanclient.paths.v2_satellite_id.get import V2SatelliteIdGet
from banyanclient.paths.v2_satellite_id.put import V2SatelliteIdPut
from banyanclient.paths.v2_satellite.post import V2SatellitePost


class SatelliteApi(
    V2ConnectorStatsGet,
    V2SatelliteGet,
    V2SatelliteIdDelete,
    V2SatelliteIdGet,
    V2SatelliteIdPut,
    V2SatellitePost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
