# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_enduser_devices_data.get import V1EnduserDevicesDataGet
from banyanclient.paths.v1_endusers_csv.get import V1EndusersCsvGet
from banyanclient.paths.v1_endusers.get import V1EndusersGet
from banyanclient.paths.v1_endusers_stats.get import V1EndusersStatsGet
from banyanclient.paths.v1_mdm_insert_devices.post import V1MdmInsertDevicesPost
from banyanclient.paths.v1_security_roles_enduser_devices.get import V1SecurityRolesEnduserDevicesGet
from banyanclient.paths.v1_unregistered_device_endusers_csv.get import V1UnregisteredDeviceEndusersCsvGet
from banyanclient.paths.v2_enduser.get import V2EnduserGet
from banyanclient.paths.v2_enduser_groups.get import V2EnduserGroupsGet
from banyanclient.paths.v2_enduser_id.get import V2EnduserIdGet
from banyanclient.paths.v2_endusers.delete import V2EndusersDelete


class EnduserApi(
    V1EnduserDevicesDataGet,
    V1EndusersCsvGet,
    V1EndusersGet,
    V1EndusersStatsGet,
    V1MdmInsertDevicesPost,
    V1SecurityRolesEnduserDevicesGet,
    V1UnregisteredDeviceEndusersCsvGet,
    V2EnduserGet,
    V2EnduserGroupsGet,
    V2EnduserIdGet,
    V2EndusersDelete,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
