# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_delete_device.delete import V1DeleteDeviceDelete
from banyanclient.paths.v1_device_id_token.get import V1DeviceIdTokenGet
from banyanclient.paths.v1_devices.get import V1DevicesGet
from banyanclient.paths.v1_devices_stats.get import V1DevicesStatsGet
from banyanclient.paths.v1_enduser_devices_data.get import V1EnduserDevicesDataGet
from banyanclient.paths.v1_enduser_devices.get import V1EnduserDevicesGet
from banyanclient.paths.v1_mdm_device_info.get import V1MdmDeviceInfoGet
from banyanclient.paths.v1_mdm_insert_devices.post import V1MdmInsertDevicesPost
from banyanclient.paths.v1_mdm_update_device.post import V1MdmUpdateDevicePost
from banyanclient.paths.v1_security_roles_enduser_devices.get import V1SecurityRolesEnduserDevicesGet
from banyanclient.paths.v1_send_device_notification.post import V1SendDeviceNotificationPost
from banyanclient.paths.v2_devices_csv.get import V2DevicesCsvGet
from banyanclient.paths.v2_devices.delete import V2DevicesDelete
from banyanclient.paths.v2_devices.get import V2DevicesGet


class DeviceApi(
    V1DeleteDeviceDelete,
    V1DeviceIdTokenGet,
    V1DevicesGet,
    V1DevicesStatsGet,
    V1EnduserDevicesDataGet,
    V1EnduserDevicesGet,
    V1MdmDeviceInfoGet,
    V1MdmInsertDevicesPost,
    V1MdmUpdateDevicePost,
    V1SecurityRolesEnduserDevicesGet,
    V1SendDeviceNotificationPost,
    V2DevicesCsvGet,
    V2DevicesDelete,
    V2DevicesGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
