# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v2_cloud_resource_id.delete import V2CloudResourceIdDelete
from banyanclient.paths.v2_cloud_resource_id.get import V2CloudResourceIdGet
from banyanclient.paths.v2_cloud_resource_id.patch import V2CloudResourceIdPatch
from banyanclient.paths.v2_cloud_resource_id.put import V2CloudResourceIdPut


class CloudResourceApi(
    V2CloudResourceIdDelete,
    V2CloudResourceIdGet,
    V2CloudResourceIdPatch,
    V2CloudResourceIdPut,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
