# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_delete_security_role.delete import V1DeleteSecurityRoleDelete
from banyanclient.paths.v1_disable_security_role.post import V1DisableSecurityRolePost
from banyanclient.paths.v1_enable_security_role.post import V1EnableSecurityRolePost
from banyanclient.paths.v1_insert_security_role.post import V1InsertSecurityRolePost
from banyanclient.paths.v1_security_roles_enduser_devices.get import V1SecurityRolesEnduserDevicesGet
from banyanclient.paths.v1_security_roles.get import V1SecurityRolesGet
from banyanclient.paths.v1_securityroles_stats.get import V1SecurityrolesStatsGet


class SecurityRoleApi(
    V1DeleteSecurityRoleDelete,
    V1DisableSecurityRolePost,
    V1EnableSecurityRolePost,
    V1InsertSecurityRolePost,
    V1SecurityRolesEnduserDevicesGet,
    V1SecurityRolesGet,
    V1SecurityrolesStatsGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
