from banyanclient.paths.v2_cloud_resource_service.get import ApiForget
from banyanclient.paths.v2_cloud_resource_service.post import ApiForpost


class V2CloudResourceService(
    ApiForget,
    ApiForpost,
):
    pass
