from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id.post import ApiForpost
from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id.delete import ApiFordelete


class V2AccessTierAccessTierIdTunnelConfigTunnelConfigId(
    ApiForpost,
    ApiFordelete,
):
    pass
