from banyanclient.paths.v2_cloud_resource_service_id.get import ApiForget
from banyanclient.paths.v2_cloud_resource_service_id.delete import ApiFordelete


class V2CloudResourceServiceId(
    ApiForget,
    ApiFordelete,
):
    pass
