from banyanclient.paths.v2_bundle_bundle_id.put import ApiForput
from banyanclient.paths.v2_bundle_bundle_id.delete import ApiFordelete


class V2BundleBundleId(
    ApiForput,
    ApiFordelete,
):
    pass
