# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v2_bundle_bundle_id.delete import V2BundleBundleIdDelete
from banyanclient.paths.v2_bundle_bundle_id.put import V2BundleBundleIdPut
from banyanclient.paths.v2_bundle_bundle_id_service.post import V2BundleBundleIdServicePost
from banyanclient.paths.v2_bundle_bundle_id_service_service_id.delete import V2BundleBundleIdServiceServiceIdDelete
from banyanclient.paths.v2_bundle.get import V2BundleGet
from banyanclient.paths.v2_bundle.post import V2BundlePost


class BundleApi(
    V2BundleBundleIdDelete,
    V2BundleBundleIdPut,
    V2BundleBundleIdServicePost,
    V2BundleBundleIdServiceServiceIdDelete,
    V2BundleGet,
    V2BundlePost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
