# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_delete_registered_service.delete import V1DeleteRegisteredServiceDelete
from banyanclient.paths.v1_disable_registered_service.post import V1DisableRegisteredServicePost
from banyanclient.paths.v1_enable_registered_service.post import V1EnableRegisteredServicePost
from banyanclient.paths.v1_insert_registered_service.post import V1InsertRegisteredServicePost
from banyanclient.paths.v1_registered_services.get import V1RegisteredServicesGet
from banyanclient.paths.v1_service_connection_test.post import V1ServiceConnectionTestPost
from banyanclient.paths.v1_services_stats.get import V1ServicesStatsGet
from banyanclient.paths.v2_access_tier_id_registered_services.get import V2AccessTierIdRegisteredServicesGet


class RegisteredServiceApi(
    V1DeleteRegisteredServiceDelete,
    V1DisableRegisteredServicePost,
    V1EnableRegisteredServicePost,
    V1InsertRegisteredServicePost,
    V1RegisteredServicesGet,
    V1ServiceConnectionTestPost,
    V1ServicesStatsGet,
    V2AccessTierIdRegisteredServicesGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
