# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_event_types.get import V1EventTypesGet
from banyanclient.paths.v1_events_count.get import V1EventsCountGet
from banyanclient.paths.v1_events_feed.get import V1EventsFeedGet
from banyanclient.paths.v1_events.get import V1EventsGet
from banyanclient.paths.v1_events.post import V1EventsPost
from banyanclient.paths.v2_event_daily_counts.get import V2EventDailyCountsGet


class EventApi(
    V1EventTypesGet,
    V1EventsCountGet,
    V1EventsFeedGet,
    V1EventsGet,
    V1EventsPost,
    V2EventDailyCountsGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
