# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.service_tunnel_id_security_policy.get import ServiceTunnelIdSecurityPolicyGet
from banyanclient.paths.service_tunnel_id_security_policy_policy_id.delete import ServiceTunnelIdSecurityPolicyPolicyIdDelete
from banyanclient.paths.service_tunnel_id_security_policy.post import ServiceTunnelIdSecurityPolicyPost
from banyanclient.paths.v2_service_tunnel.get import V2ServiceTunnelGet
from banyanclient.paths.v2_service_tunnel_id.delete import V2ServiceTunnelIdDelete
from banyanclient.paths.v2_service_tunnel_id.get import V2ServiceTunnelIdGet
from banyanclient.paths.v2_service_tunnel_id.put import V2ServiceTunnelIdPut
from banyanclient.paths.v2_service_tunnel.post import V2ServiceTunnelPost


class ServiceTunnelApi(
    ServiceTunnelIdSecurityPolicyGet,
    ServiceTunnelIdSecurityPolicyPolicyIdDelete,
    ServiceTunnelIdSecurityPolicyPost,
    V2ServiceTunnelGet,
    V2ServiceTunnelIdDelete,
    V2ServiceTunnelIdGet,
    V2ServiceTunnelIdPut,
    V2ServiceTunnelPost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
