from banyanclient.paths.service_tunnel_id_security_policy.get import ApiForget
from banyanclient.paths.service_tunnel_id_security_policy.post import ApiForpost


class ServiceTunnelIdSecurityPolicy(
    ApiForget,
    ApiForpost,
):
    pass
