# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.service_tunnel_id_security_policy.get import ServiceTunnelIdSecurityPolicyGet
from banyanclient.paths.service_tunnel_id_security_policy_policy_id.delete import ServiceTunnelIdSecurityPolicyPolicyIdDelete
from banyanclient.paths.service_tunnel_id_security_policy.post import ServiceTunnelIdSecurityPolicyPost
from banyanclient.paths.v1_delete_security_attach_policy.delete import V1DeleteSecurityAttachPolicyDelete
from banyanclient.paths.v1_delete_security_policy.delete import V1DeleteSecurityPolicyDelete
from banyanclient.paths.v1_insert_security_attach_policy.post import V1InsertSecurityAttachPolicyPost
from banyanclient.paths.v1_insert_security_policy.post import V1InsertSecurityPolicyPost
from banyanclient.paths.v1_policies_stats.get import V1PoliciesStatsGet
from banyanclient.paths.v1_policy_attachment_attached_to_type_attached_to_id.get import V1PolicyAttachmentAttachedToTypeAttachedToIdGet
from banyanclient.paths.v1_policy_attachment_attached_to_type.get import V1PolicyAttachmentAttachedToTypeGet
from banyanclient.paths.v1_policy_attachment.get import V1PolicyAttachmentGet
from banyanclient.paths.v1_policy_policy_id_attachment.get import V1PolicyPolicyIdAttachmentGet
from banyanclient.paths.v1_security_attach_policies.get import V1SecurityAttachPoliciesGet
from banyanclient.paths.v1_security_policies.get import V1SecurityPoliciesGet


class SecurityPolicyApi(
    ServiceTunnelIdSecurityPolicyGet,
    ServiceTunnelIdSecurityPolicyPolicyIdDelete,
    ServiceTunnelIdSecurityPolicyPost,
    V1DeleteSecurityAttachPolicyDelete,
    V1DeleteSecurityPolicyDelete,
    V1InsertSecurityAttachPolicyPost,
    V1InsertSecurityPolicyPost,
    V1PoliciesStatsGet,
    V1PolicyAttachmentAttachedToTypeAttachedToIdGet,
    V1PolicyAttachmentAttachedToTypeGet,
    V1PolicyAttachmentGet,
    V1PolicyPolicyIdAttachmentGet,
    V1SecurityAttachPoliciesGet,
    V1SecurityPoliciesGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
